@@ -17,6 +17,8 @@
 #include <QDebug>
 
 #include <QMap>
+#include <QRegExp>
+#include <QRegularExpression>
 
 namespace KCDDB
 {
@@ -108,7 +110,7 @@ namespace KCDDB
       set(const QString& type, const QVariant &d)
       {
         //qDebug() << "set: " << type << ", " << d.toString();
-        if(type.contains(QRegExp( QLatin1String( "^T.*_.*$" )) )){
+        if(type.contains(QRegularExpression( QLatin1String( "^T.*_.*$" )) )){
 		  qCDebug(LIBKCDDB) << "Error: custom cdinfo::set data can not start with T and contain a _";
           return;
         }
@@ -269,11 +271,7 @@ namespace KCDDB
     bool
   CDInfo::load(const QString & string)
   {
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
-    return load(string.split(QLatin1Char( '\n' ),QString::SkipEmptyParts));
-#else
     return load(string.split(QLatin1Char( '\n' ),Qt::SkipEmptyParts));
-#endif
   }
 
     bool
@@ -287,12 +285,12 @@ namespace KCDDB
     QStringList::ConstIterator it = lineList.begin();
 
     QRegExp rev(QLatin1String( "# Revision: (\\d+)" ));
-    QRegExp eol(QLatin1String( "[\r\n]" ));
+    const static QRegularExpression eol(QLatin1String( "[\r\n]" ));
 
     while ( it != lineList.end() )
     {
       QString line(*it);
-      line.replace(eol,QLatin1String( "" ));
+      line.remove(eol);
       ++it;
 
       if (rev.indexIn(line) != -1)
@@ -350,7 +348,7 @@ namespace KCDDB
         uint trackNumber = key.mid( key.indexOf(QLatin1Char( '_' ))+1 ).toUInt();
         checkTrack( trackNumber );
 
-        QRegExp data(QString::fromLatin1("^T.*_%1$").arg(trackNumber));
+        QRegularExpression data(QString::fromLatin1("^T.*_%1$").arg(trackNumber));
         if  ( key.contains( data ) )
         {
           QString k = key.mid(1, key.indexOf(QLatin1Char( '_' ))-1);
